#
# spec file for package python-sat-stac
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define packagename sat-stac
Name:           python-sat-stac
Version:        0.4.1
Release:        4.2
Summary:        A library for reading and working with Spatio-Temporal Asset Catalogs
License:        MIT
URL:            https://github.com/sat-utils/sat-stac
Source:         https://files.pythonhosted.org/packages/source/s/sat-stac/sat-stac-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#sat-utils/sat-stac#75
Patch0:         use-importlib.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil >= 2.7.5}
BuildRequires:  %{python_module requests >= 2.19.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.7.5
Requires:       python-requests >= 2.19.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Sat-search is a Python 3 library and a command line tool for discovering
and downloading publicly available satellite imagery using a conformant
API such as sat-api.

%prep
%autosetup -p1 -n %{packagename}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
for p in %{packagename} ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

%post
%python_install_alternative %{packagename}

%postun
%python_uninstall_alternative %{packagename}

%check
# This archive does not have test files.
# The archive in github has it, but need network connection for test.

%files %{python_files}
%doc README.md
%python_alternative %{_bindir}/%{packagename}
%{python_sitelib}/satstac
%{python_sitelib}/sat_stac-%{version}.dist-info

%changelog
* Wed Dec  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Stop skipping on Python versions.
- Add patch use-importlib.patch:
  * Use importlib to support Python 3.12+
- Switch to autosetup and pyproject macros.
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- skip build on python313 as well
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip building for python312
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.4.1
  Added
  * User can now provide custom headers to download function
  * id and description keywords added to itemcollection.save() and itemcollection.geojson() for user to supply values to save single file STAC
  Changed
  * Allow reading in of ItemCollections without collections
  * Default STAC_VERSION updated to 1.0.0-beta.2
  Fixed
  * Saved ItemCollections now adhere to STAC single-file-stac spec
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix download url
* Mon Aug 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix few minor issues with alternatives
* Fri Jul 31 2020 andy great <andythe_great@pm.me>
- Update spec file to use python alternative.
* Sun Jul 26 2020 andy great <andythe_great@pm.me>
- Initial package release.
